library(devtools)
library(likert)
require(gridExtra)
library(repr)
library(cowplot)
library(dplyr)

survey = read.csv(file="survey_raw.csv", header = FALSE, sep=",")

summary(survey)
survey[survey == 'I\'m not sure'] <- NA

mylevels <- c("Strongly disagree", "Somewhat disagree", "Neither agree nor disagree", "Somewhat agree", "Strongly agree")


# make sure all columns have all the levels (otherwise 'likert' function breaks)
for(i in seq_along(survey)) {
  survey[,i] <- factor(survey[,i], levels=mylevels)
}

#setting bar size likert graphs
size_collumn = 0.5

#### Ideology

survey_ideology = select(survey, V1, V2, V3)
x <- likert(survey_ideology)

x$results$Item <- c("Q1", 
                    "Q2",
                    "Q3")

colnames(x$items) = c("Q1", 
                      "Q2",
                      "Q3")

#title = "I contribute to F/OSS because..."
title = "Ideology (Intrinsic)"

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot1 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot1$layers[[1]]$geom_params$width = size_collumn
plot1$layers[[2]]$geom_params$width = size_collumn
plot1$layers[[3]]$geom_params$width = size_collumn
plot1

survey_altruism = select(survey, V4, V5, V6)
x <- likert(survey_altruism)
title = "Altruism (Intrinsic)"

x$results$Item <- c("Q4",
                    "Q5",
                    "Q6")

colnames(x$items) = c("Q4",
                      "Q5",
                      "Q6")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot2 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot2$layers[[1]]$geom_params$width = size_collumn
plot2$layers[[2]]$geom_params$width = size_collumn
plot2$layers[[3]]$geom_params$width = size_collumn
plot2

#### Fun
survey_fun = select(survey, V7, V8)
x <- likert(survey_fun)
title = "Fun (Intrinsic)"

x$results$Item <- c("Q7",
  "Q8")

colnames(x$items) = c("Q7",
  "Q8")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot3 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot3$layers[[2]]$geom_params$width = 0.3
plot3$layers[[3]]$geom_params$width = 0.3

plot3

##### Kinship
survey_kinship = select(survey, V9, V10)
x <- likert(survey_kinship)
title = "Kinship (Intrinsic)"

x$results$Item <- c("Q9",
                    "Q10")

colnames(x$items) = c("Q9",
                      "Q10")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(legend.text = element_text(size = rel(2), hjust = 0.5), legend.title = element_blank(), plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot4 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot4$layers[[2]]$geom_params$width = 0.3
plot4$layers[[3]]$geom_params$width = 0.3
plot4

#### Reputation
survey_reputation = select(survey, V11)
x <- likert(survey_reputation)
title = "Reputation  (Internalized Extrinsic)"

x$results$Item <- c("Q11")

colnames(x$items) = c("Q11")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot5 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot5$layers[[2]]$geom_params$width = 0.3
plot5

#### Gift-Reciprocity
survey_gift = select(survey, V12)
x <- likert(survey_gift)
title = "Reciprocity (Internalized Extrinsic)"

x$results$Item <- c("Q12")

colnames(x$items) = c("Q12")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot6 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot6$layers[[2]]$geom_params$width = 0.3
plot6

#### Learning
survey_learning = select(survey, V15)
x <- likert(survey_learning)
title = "Learning (Internalized Extrinsic)"

x$results$Item <- c("Q13")

colnames(x$items) = c("Q13")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot7 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot7$layers[[3]]$geom_params$width = 0.3
plot7

#### Own-use

survey_own_use = select(survey, V17, V18, V19, V20, V21)
x <- likert(survey_own_use)
title = "Own-use (Internalized Extrinsic)"

x$results$Item <- c("Q14",	
                    "Q15",	
                    "Q16",
                    "Q17",
                    "Q18")

colnames(x$items) = c("Q14",	
                      "Q15",	
                      "Q16",
                      "Q17",
                      "Q18")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot8 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot8$layers[[1]]$geom_params$width = size_collumn
plot8$layers[[2]]$geom_params$width = size_collumn
plot8$layers[[3]]$geom_params$width = size_collumn
plot8$layers[[4]]$geom_params$width = size_collumn
plot8$layers[[5]]$geom_params$width = size_collumn
plot8

###### Career
survey_career = select(survey, V22)
x <- likert(survey_career)
title = "Career (Extrinsic)"

x$results$Item <- c("Q19")

colnames(x$items) = c("Q19")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)
knitr::opts_chunk$set(fig.height = knitr::opts_chunk$get('fig.height')*2)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot9 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot9$layers[[3]]$geom_params$width = 0.3
plot9


###### Pay
survey_pay = select(survey, V23, V24)
x <- likert(survey_pay)
title = "Pay (Extrinsic)"

x$results$Item <- c("Q20",	
                    "Q21")

colnames(x$items) = c("Q20",	
                      "Q21")

scale_height = knitr::opts_chunk$get('fig.height')*0.5
scale_width = knitr::opts_chunk$get('fig.width')*1.25
knitr::opts_chunk$set(fig.height = scale_height, fig.width = scale_width)

theme_update(plot.title = element_text(color="black", hjust = 0.5, size=10, face="bold")) 

plot10 = likert.bar.plot(x, centered = T, group.order = x$results$Item, legend.position="none") + theme(text = element_text(size = rel(4),color="black", face="bold"), axis.title.x=element_blank()) + ggtitle(title)
plot10$layers[[2]]$geom_params$width = 0.3
plot10$layers[[3]]$geom_params$width = 0.3
plot10

pdf("likert_by_motivation_side.pdf", width=15, height=8)
grid.arrange(plot1, plot2, plot3, plot4, plot5, plot6, plot7, plot8, plot9, plot10, ncol=2)
dev.off()
